pub struct DiagnosticsReporter<'a> { /* private fields */ }
Collects compilation diagnostics and presents them in preconfigured way.

Implementations

source

impl DiagnosticsReporter<'static>

source

pub fn ignoring() -> Self

Create a reporter which does not print or collect diagnostics at all.

source

pub fn stderr() -> Self

Create a reporter which prints all diagnostics to std::io::Stderr.

source

impl<'a> DiagnosticsReporter<'a>

source

pub fn callback(callback: impl FnMut(FormattedDiagnosticEntry) + 'a) -> Self

Create a reporter which calls callback for each diagnostic.

source

pub fn write_to_string(string: &'a mut String) -> Self

Create a reporter which appends all diagnostics to provided string.

source

pub fn with_crates(self, crate_ids: &[CrateId]) -> Self

Sets crates to be checked, instead of all crates in the db.

source

pub fn with_ignore_warnings_crates(self, crate_ids: &[CrateId]) -> Self

Ignore warnings in these crates. This does not modify the set of crates to be checked. Adding crates that are not checked here has no effect. To change the set of crates to be checked, use with_crates.

source

pub fn allow_warnings(self) -> Self

Allows the compilation to succeed if only warnings are emitted.

source

pub fn check(&mut self, db: &RootDatabase) -> bool

Checks if there are diagnostics and reports them to the provided callback as strings. Returns true if diagnostics were found.

source

pub fn ensure(&mut self, db: &RootDatabase) -> Result<(), DiagnosticsError>

Checks if there are diagnostics and reports them to the provided callback as strings. Returns Err if diagnostics were found.